InputStamper

Struct InputStamper 

pub struct InputStamper { /* private fields */ }
The timestamper for DI0 reference clock inputs.

Implementations

Source

impl InputStamper

pub fn new(trigger: PA3<Alternate<2>>, timer_channel: Channel4) -> Self

Construct the DI0 input timestamper.

Args
  • trigger - The capture trigger input pin.
  • `timer_channel - The timer channel used for capturing timestamps.
pub fn start(&mut self)

Start to capture timestamps on DI0.

pub fn latest_timestamp(&mut self) -> Result<Option<u32>, Option<u32>>

Get the latest timestamp that has occurred.

Note

This function must be called at least as often as timestamps arrive. If an over-capture event occurs, this function will clear the overflow, and return a new timestamp of unknown recency an Err(). Note that this indicates at least one timestamp was inadvertently dropped.